==> connector-service-1.0.0-20190312.083317-14-sources.jar: com/bizvane/connectorservice/entity/vo/MongoExecptionVO.java <==
package com.bizvane.connectorservice.entity.vo;

public class MongoExecptionVO {

    private String sessionTokenId;

    private Long onlineBrandId;

    private String requestType;

    private String requestUrl;

    private String param;

    private Long requestTime;

    private String method;

    private String errorMessage;

    private String companyCode;

    public String getCompanyCode() {
        return companyCode;
    }

    public void setCompanyCode(String companyCode) {
        this.companyCode = companyCode;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public String getSessionTokenId() {
        return sessionTokenId;
    }

    public void setSessionTokenId(String sessionTokenId) {
        this.sessionTokenId = sessionTokenId;
    }

    public Long getOnlineBrandId() {
        return onlineBrandId;
    }

    public void setOnlineBrandId(Long onlineBrandId) {
        this.onlineBrandId = onlineBrandId;
    }

    public String getRequestType() {
        return requestType;
    }

    public void setRequestType(String requestType) {
        this.requestType = requestType;
    }

    public String getRequestUrl() {
        return requestUrl;
    }

    public void setRequestUrl(String requestUrl) {
        this.requestUrl = requestUrl;
    }

    public String getParam() {
        return param;
    }

    public void setParam(String param) {
        this.param = param;
    }

    public Long getRequestTime() {
        return requestTime;
    }

    public void setRequestTime(Long requestTime) {
        this.requestTime = requestTime;
    }

    public String getMethod() {
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }
}

==> connector-service-1.0.0-20191029.064719-80-sources.jar: com/bizvane/connectorservice/entity/vo/MongoExecptionVO.java <==
package com.bizvane.connectorservice.entity.vo;

import java.io.Serializable;

public class MongoExecptionVO implements Serializable {

    private String sessionTokenId;

    private Long onlineBrandId;

    private String requestType;

    private String requestUrl;

    private String param;

    private Long requestTime;

    private String method;

    private String errorMessage;

    private String companyCode;

    public String getCompanyCode() {
        return companyCode;
    }

    public void setCompanyCode(String companyCode) {
        this.companyCode = companyCode;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public String getSessionTokenId() {
        return sessionTokenId;
    }

    public void setSessionTokenId(String sessionTokenId) {
        this.sessionTokenId = sessionTokenId;
    }

    public Long getOnlineBrandId() {
        return onlineBrandId;
    }

    public void setOnlineBrandId(Long onlineBrandId) {
        this.onlineBrandId = onlineBrandId;
    }

    public String getRequestType() {
        return requestType;
    }

    public void setRequestType(String requestType) {
        this.requestType = requestType;
    }

    public String getRequestUrl() {
        return requestUrl;
    }

    public void setRequestUrl(String requestUrl) {
        this.requestUrl = requestUrl;
    }

    public String getParam() {
        return param;
    }

    public void setParam(String param) {
        this.param = param;
    }

    public Long getRequestTime() {
        return requestTime;
    }

    public void setRequestTime(Long requestTime) {
        this.requestTime = requestTime;
    }

    public String getMethod() {
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }
}
